{% load i18n %}
<link rel="stylesheet" type="text/css" href="//cdnjs.cloudflare.com/ajax/libs/cookieconsent2/3.1.0/cookieconsent.min.css" />
<script src="//cdnjs.cloudflare.com/ajax/libs/cookieconsent2/3.1.0/cookieconsent.min.js"></script>
<script>
window.addEventListener("load", function(){
window.cookieconsent.initialise({
  "palette": {
    "popup": {
      "background": "#ffffff",
      "text": "#000000"
    },
    "button": {
      "background": "#00bea4",
      "text": "#ffffff"
    }
  },
  "theme": "classic",
  "position": "bottom-right",
  "content": {
    "message": "{% trans 'This website uses cookies to ensure you get the best experience on our website.' %}",
    "dismiss": "{% trans 'GOT IT!' %}",
    "link": "{% trans 'Learn more' %}",
    "href": "https://www.example.com/cookie_policy/"
  }
})});
</script>
