# Generated by Django 2.2.17 on 2021-03-18 13:56

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_sso_app', '0007_auto_20210222_1526'),
    ]

    operations = [
        migrations.CreateModel(
            name='Grouping',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('path', models.CharField(max_length=255, unique=True)),
                ('depth', models.PositiveIntegerField()),
                ('numchild', models.PositiveIntegerField(default=0)),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='created at')),
                ('name', models.CharField(max_length=150, verbose_name='name')),
                ('type', models.CharField(blank=True, max_length=255, null=True, verbose_name='type')),
                ('description', models.TextField(blank=True, null=True, verbose_name='description')),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_sso_app.Group')),
            ],
            options={
                'verbose_name': 'Grouping',
            },
        ),
    ]
