# Generated by Django 2.2.17 on 2021-03-19 13:02

from django.db import migrations, models
import django_countries.fields


class Migration(migrations.Migration):

    dependencies = [
        ('django_sso_app', '0008_grouping'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='company_name',
            field=django_countries.fields.CountryField(blank=True, max_length=255, null=True, verbose_name='company name'),
        ),
        migrations.AddField(
            model_name='profile',
            name='country_of_birth',
            field=django_countries.fields.CountryField(blank=True, max_length=46, null=True, verbose_name='country of birth'),
        ),
        migrations.AddField(
            model_name='profile',
            name='expiration_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='expiration date'),
        ),
        migrations.AddField(
            model_name='profile',
            name='external_id',
            field=models.CharField(blank=True, db_index=True, max_length=36, null=True, verbose_name='external id'),
        ),
        migrations.AddField(
            model_name='profile',
            name='gender',
            field=models.CharField(blank=True, max_length=15, null=True, verbose_name='gender'),
        ),
    ]
