{% extends "base.html" %}
{% load static i18n %}

{% block title %}{{ block.super }} - {% block head_title %}{% endblock head_title %}{% endblock title %}

{% block css %}
{{ block.super }}
<!-- Your stuff: Third-party CSS libraries go here -->
<link rel="stylesheet" href="https://unpkg.com/leaflet@1.6.0/dist/leaflet.css"
  integrity="sha512-xwE/Az9zrjBIphAcBb3F6JVqxf46+CDLwfLMHloNu6KEQCAWi6HcDUbeOfBIptF7tcCzusKFjFw2yuvEpDL9wQ=="
  crossorigin=""/>
<!-- This file stores accounts-specific CSS -->
<link href="{% static 'css/accounts.css' %}" rel="stylesheet">
{% endblock css %}

{% block content %}
<div class="container container-full">
    <div class="row">
        <div class="col-md-8 offset-md-2 col-lg-6 offset-lg-3">
        {% block inner %}{% endblock %}
        </div>
    </div>
</div>
{% endblock %}


{% block javascript %}
{{ block.super }}
<!-- Make sure you put this AFTER Leaflet's CSS -->
<script src="https://unpkg.com/leaflet@1.6.0/dist/leaflet.js"
integrity="sha512-gZwIG9x3wUXg2hdXF6+rVkLF/0Vi9U8D2Ntg4Ga5I5BZpVkVxlJWbSQtXPSiUTtC0TjtGOmxa1AJPuV0CPthew=="
crossorigin=""></script>
<!-- place project specific Javascript in this file -->
<script src="{% static 'js/accounts.js' %}"></script>
<!-- Your stuff: Third-party javascript libraries go here -->
{% endblock javascript %}