{% extends "email/base_email.html" %}{% load i18n %}
{% block welcome %}
{% blocktrans %}Hello from {{ EMAILS_SITE_NAME }}!{% endblocktrans %}
{% endblock%}

{% block content %}
{% blocktrans %}You're receiving this e-mail because you or someone else has requested a password for your user account.
It can be safely ignored if you did not request a password reset. Click the link below to reset your password.{% endblocktrans %}
<br /><br />

{% comment %}
rest_auth or allauth forms
{% endcomment %}
<a href="{% if password_reset_url %}{{ password_reset_url }}{% else %}{{ protocol }}://{{ EMAILS_DOMAIN }}{% url 'restauth_password_reset_confirm' uidb64=uid token=token %}{% endif %}">
    {% if password_reset_url %}{{ password_reset_url }}{% else %}{{ protocol }}://{{ EMAILS_DOMAIN }}{% url 'restauth_password_reset_confirm' uidb64=uid token=token %}{% endif %}
</a>

<br /><br />
{% if username %}{% blocktrans %}In case you forgot, your username is {{ username }}.{% endblocktrans %}<br />
{% endif %}{% blocktrans %}Thank you for using {{ EMAILS_SITE_NAME }}!{% endblocktrans %}
{% endblock%}
