# Generated by Django 2.2.9 on 2020-03-07 10:35

from django.db import migrations, models
import django_countries.fields


class Migration(migrations.Migration):

    dependencies = [
        ('django_sso_app', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='groups',
            field=models.ManyToManyField(blank=True, related_name='sso_app_profiles', related_query_name='sso_app_profile', to='django_sso_app.Group', verbose_name='groups'),
        ),
        migrations.AlterField(
            model_name='profile',
            name='country',
            field=django_countries.fields.CountryField(blank=True, max_length=46, null=True, verbose_name='country'),
        ),
        migrations.AlterField(
            model_name='service',
            name='groups',
            field=models.ManyToManyField(blank=True, related_name='sso_app_services', related_query_name='sso_app_service', to='django_sso_app.Group', verbose_name='groups'),
        ),
    ]
