{% extends "account/base.html" %}

{% load i18n %}

{% block head_title %}{% trans "Verify Your E-mail Address" %}{% endblock head_title %}

{% block inner %}
    <h1>{% trans "Verify Your E-mail Address" %}</h1>

    <p>{% blocktrans %}We have sent an e-mail to you for verification. Follow the link provided to finalize the signup process. Please contact us if you do not receive it within a few minutes.{% endblocktrans %}</p>

{% endblock %}

