{% extends "account/base.html" %}

{% load i18n %}
{% block head_title %}{% trans "Change Password" %}{% endblock head_title %}

{% block inner %}
    <h1>{% trans "Change Password" %}</h1>
    <p>{% trans 'Your password is now changed.' %}</p>
{% endblock %}

